@@ -8,7 +8,7 @@ use Config;
 use File::Spec::Functions;
 use File::Temp qw( tempdir );
 use Cwd;
-use Capture::Tiny qw( capture );
+use IPC::Run3;
 
 # use an absolute pathname in case a test chdir()s
 my $pp = catfile(getcwd(), qw( blib script pp ));
@@ -20,7 +20,9 @@ sub pp_ok
     my $exe = catfile($ENV{PAR_TMPDIR},"packed$Config{_exe}");
     unlink($exe);
 
-    system($^X, $pp, -o => $exe, @_);
+    die "system(LIST) with double quotes in LIST doesn't work on Windows: @_"
+        if grep { /"/ } @_;
+    system($^X, "-Mblib", $pp, -o => $exe, @_);
     # Note: -x is unreliable on Windows
     ok( $? == 0 && -f $exe, qq[successfully packed "$exe"] );
 
@@ -32,8 +34,9 @@ sub run_ok
 {
     my @cmd = @_;
 
-    my ($out, $err) = capture { system(@cmd) };
-    ok( $? == 0, qq[successfully ran "@cmd"] );
+    my ($out, $err);
+    run3(\@cmd, \undef, \$out, \$err);
+    is( $?, 0, qq[successfully ran "@cmd"] );
 
     return ($out, $err);
 }
